@@ -11,6 +11,7 @@ import aiohttp
 import requests
 
 from fsspec.asyn import AsyncFileSystem, sync, sync_wrapper
+from fsspec.exceptions import FSTimeoutError
 from fsspec.spec import AbstractBufferedFile
 from fsspec.utils import DEFAULT_BLOCK_SIZE, tokenize
 
@@ -26,6 +27,14 @@ async def get_client(**kwargs):
     return aiohttp.ClientSession(**kwargs)
 
 
+class BlockSizeError(ValueError):
+    """
+    Helper class for exceptions raised in this module.
+    """
+
+    pass
+
+
 class HTTPFileSystem(AsyncFileSystem):
     """
     Simple File-System for fetching data via HTTP(S)
@@ -104,7 +113,7 @@ class HTTPFileSystem(AsyncFileSystem):
             try:
                 sync(loop, session.close, timeout=0.1)
                 return
-            except TimeoutError:
+            except (TimeoutError, FSTimeoutError):
                 pass
         if session._connector is not None:
             # close after loop is dead
@@ -137,7 +146,7 @@ class HTTPFileSystem(AsyncFileSystem):
         logger.debug(url)
         session = await self.set_session()
         async with session.get(url, **self.kwargs) as r:
-            r.raise_for_status()
+            self._raise_not_found_for_status(r, url)
             text = await r.text()
         if self.simple_links:
             links = ex2.findall(text) + [u[2] for u in ex.findall(text)]
@@ -189,21 +198,28 @@ class HTTPFileSystem(AsyncFileSystem):
 
     ls = sync_wrapper(_ls)
 
+    def _raise_not_found_for_status(self, response, url):
+        """
+        Raises FileNotFoundError for 404s, otherwise uses raise_for_status.
+        """
+        if response.status == 404:
+            raise FileNotFoundError(url)
+        response.raise_for_status()
+
     async def _cat_file(self, url, start=None, end=None, **kwargs):
         kw = self.kwargs.copy()
         kw.update(kwargs)
         logger.debug(url)
-        if (start is None) ^ (end is None):
-            raise ValueError("Give start and end or neither")
-        if start is not None:
+
+        # TODO: extract into testable utility function?
+        if start is not None or end is not None:
             headers = kw.pop("headers", {}).copy()
-            headers["Range"] = "bytes=%i-%i" % (start, end - 1)
+
+            headers["Range"] = await self._process_limits(url, start, end)
             kw["headers"] = headers
         session = await self.set_session()
         async with session.get(url, **kw) as r:
-            if r.status == 404:
-                raise FileNotFoundError(url)
-            r.raise_for_status()
+            self._raise_not_found_for_status(r, url)
             out = await r.read()
         return out
 
@@ -213,9 +229,7 @@ class HTTPFileSystem(AsyncFileSystem):
         logger.debug(rpath)
         session = await self.set_session()
         async with session.get(rpath, **self.kwargs) as r:
-            if r.status == 404:
-                raise FileNotFoundError(rpath)
-            r.raise_for_status()
+            self._raise_not_found_for_status(r, rpath)
             with open(lpath, "wb") as fd:
                 chunk = True
                 while chunk:
@@ -530,8 +544,9 @@ class HTTPFile(AbstractBufferedFile):
                     # data size OK
                     out = await r.read()
                 else:
-                    raise ValueError(
-                        "Got more bytes (%i) than requested (%i)" % (cl, end - start)
+                    raise BlockSizeError(
+                        "Got more bytes so far (>%i) than requested (%i)"
+                        % (cl, end - start)
                     )
             else:
                 cl = 0
@@ -543,7 +558,7 @@ class HTTPFile(AbstractBufferedFile):
                         out.append(chunk)
                         cl += len(chunk)
                         if cl > end - start:
-                            raise ValueError(
+                            raise BlockSizeError(
                                 "Got more bytes so far (>%i) than requested (%i)"
                                 % (cl, end - start)
                             )
@@ -656,6 +671,9 @@ async def _file_size(url, session=None, size_policy="head", **kwargs):
     else:
         raise TypeError('size_policy must be "head" or "get", got %s' "" % size_policy)
     async with r:
+        # TODO:
+        #  recognise lack of 'Accept-Ranges', or  'Accept-Ranges': 'none' (not 'bytes')
+        #  to mean streaming only, no random access => return None
         if "Content-Length" in r.headers:
             return int(r.headers["Content-Length"])
         elif "Content-Range" in r.headers:
