@@ -7,6 +7,8 @@ import shutil
 import tempfile
 
 from fsspec import AbstractFileSystem
+from fsspec.compression import compr
+from fsspec.core import get_compression
 from fsspec.utils import stringify_path
 
 
@@ -31,6 +33,8 @@ class LocalFileSystem(AbstractFileSystem):
 
     def mkdir(self, path, create_parents=True, **kwargs):
         path = self._strip_protocol(path)
+        if self.exists(path):
+            raise FileExistsError(path)
         if create_parents:
             self.makedirs(path, exist_ok=True)
         else:
@@ -56,17 +60,7 @@ class LocalFileSystem(AbstractFileSystem):
         return super().glob(path, **kwargs)
 
     def info(self, path, **kwargs):
-        if isinstance(path, str):
-            path = self._strip_protocol(path)
-            out = os.stat(path, follow_symlinks=False)
-            link = os.path.islink(path)
-            if os.path.isdir(path):
-                t = "directory"
-            elif os.path.isfile(path):
-                t = "file"
-            else:
-                t = "other"
-        else:
+        if isinstance(path, os.DirEntry):
             # scandir DirEntry
             out = path.stat(follow_symlinks=False)
             link = path.is_symlink()
@@ -77,6 +71,17 @@ class LocalFileSystem(AbstractFileSystem):
             else:
                 t = "other"
             path = self._strip_protocol(path.path)
+        else:
+            # str or path-like
+            path = self._strip_protocol(path)
+            out = os.stat(path, follow_symlinks=False)
+            link = os.path.islink(path)
+            if os.path.isdir(path):
+                t = "directory"
+            elif os.path.isfile(path):
+                t = "file"
+            else:
+                t = "other"
         result = {
             "name": path,
             "size": out.st_size,
@@ -119,11 +124,18 @@ class LocalFileSystem(AbstractFileSystem):
         shutil.move(path1, path2)
 
     def rm(self, path, recursive=False, maxdepth=None):
-        path = self._strip_protocol(path).rstrip("/")
-        if recursive and self.isdir(path):
-            shutil.rmtree(path)
-        else:
-            os.remove(path)
+        if isinstance(path, str):
+            path = [path]
+
+        for p in path:
+            p = self._strip_protocol(p).rstrip("/")
+            if recursive and self.isdir(p):
+
+                if os.path.abspath(p) == os.getcwd():
+                    raise ValueError("Cannot delete current working directory")
+                shutil.rmtree(p)
+            else:
+                os.remove(p)
 
     def _open(self, path, mode="rb", block_size=None, **kwargs):
         path = self._strip_protocol(path)
@@ -161,7 +173,7 @@ class LocalFileSystem(AbstractFileSystem):
         path = stringify_path(path)
         if path.startswith("file://"):
             path = path[7:]
-        return make_path_posix(path)
+        return make_path_posix(path).rstrip("/")
 
     def _isfilestore(self):
         # Inheriting from DaskFileSystem makes this False (S3, etc. were)
@@ -171,7 +183,7 @@ class LocalFileSystem(AbstractFileSystem):
 
 
 def make_path_posix(path, sep=os.sep):
-    """ Make path generic """
+    """Make path generic"""
     if isinstance(path, (list, set, tuple)):
         return type(path)(make_path_posix(p) for p in path)
     if "~" in path:
@@ -210,12 +222,15 @@ def make_path_posix(path, sep=os.sep):
 
 
 class LocalFileOpener(io.IOBase):
-    def __init__(self, path, mode, autocommit=True, fs=None, **kwargs):
+    def __init__(
+        self, path, mode, autocommit=True, fs=None, compression=None, **kwargs
+    ):
         self.path = path
         self.mode = mode
         self.fs = fs
         self.f = None
         self.autocommit = autocommit
+        self.compression = get_compression(path, compression)
         self.blocksize = io.DEFAULT_BUFFER_SIZE
         self._open()
 
@@ -223,6 +238,9 @@ class LocalFileOpener(io.IOBase):
         if self.f is None or self.f.closed:
             if self.autocommit or "w" not in self.mode:
                 self.f = open(self.path, mode=self.mode)
+                if self.compression:
+                    compress = compr[self.compression]
+                    self.f = compress(self.f, mode=self.mode)
             else:
                 # TODO: check if path is writable?
                 i, name = tempfile.mkstemp()
