@@ -1,11 +1,13 @@
-from __future__ import print_function, division, absolute_import
+from __future__ import absolute_import, division, print_function
 
 import zipfile
-from fsspec import AbstractFileSystem, open_files
-from fsspec.utils import tokenize, DEFAULT_BLOCK_SIZE
+
+from fsspec import open_files
+from fsspec.archive import AbstractArchiveFileSystem
+from fsspec.utils import DEFAULT_BLOCK_SIZE
 
 
-class ZipFileSystem(AbstractFileSystem):
+class ZipFileSystem(AbstractArchiveFileSystem):
     """Read contents of ZIP archive as a file-system
 
     Keeps file object open while instance lives.
@@ -14,6 +16,7 @@ class ZipFileSystem(AbstractFileSystem):
     """
 
     root_marker = ""
+    protocol = "zip"
 
     def __init__(
         self,
@@ -22,7 +25,7 @@ class ZipFileSystem(AbstractFileSystem):
         target_protocol=None,
         target_options=None,
         block_size=DEFAULT_BLOCK_SIZE,
-        **kwargs
+        **kwargs,
     ):
         """
         Parameters
@@ -63,7 +66,10 @@ class ZipFileSystem(AbstractFileSystem):
     def _get_dirs(self):
         if self.dir_cache is None:
             files = self.zip.infolist()
-            self.dir_cache = {}
+            self.dir_cache = {
+                dirname + "/": {"name": dirname + "/", "size": 0, "type": "directory"}
+                for dirname in self._all_dirnames(self.zip.namelist())
+            }
             for z in files:
                 f = {s: getattr(z, s) for s in zipfile.ZipInfo.__slots__}
                 f.update(
@@ -75,41 +81,6 @@ class ZipFileSystem(AbstractFileSystem):
                 )
                 self.dir_cache[f["name"]] = f
 
-    def ls(self, path, detail=False, **kwargs):
-        self._get_dirs()
-        paths = {}
-        for p, f in self.dir_cache.items():
-            p = p.rstrip("/")
-            if "/" in p:
-                root = p.rsplit("/", 1)[0]
-            else:
-                root = ""
-            if root == path.rstrip("/"):
-                paths[p] = f
-            elif path and all(
-                (a == b) for a, b in zip(path.split("/"), p.strip("/").split("/"))
-            ):
-                # implicit directory
-                ppath = "/".join(p.split("/")[: len(path.split("/")) + 1])
-                if ppath not in paths:
-                    out = {"name": ppath + "/", "size": 0, "type": "directory"}
-                    paths[ppath] = out
-
-            elif all(
-                (a == b)
-                for a, b in zip(path.split("/"), [""] + p.strip("/").split("/"))
-            ):
-                # root directory entry
-                ppath = p.rstrip("/").split("/", 1)[0]
-                if ppath not in paths:
-                    out = {"name": ppath + "/", "size": 0, "type": "directory"}
-                    paths[ppath] = out
-        out = list(paths.values())
-        if detail:
-            return out
-        else:
-            return list(sorted(f["name"] for f in out))
-
     def cat(self, path):
         return self.zip.read(path)
 
@@ -120,7 +91,7 @@ class ZipFileSystem(AbstractFileSystem):
         block_size=None,
         autocommit=True,
         cache_options=None,
-        **kwargs
+        **kwargs,
     ):
         path = self._strip_protocol(path)
         if mode != "rb":
@@ -130,6 +101,3 @@ class ZipFileSystem(AbstractFileSystem):
         out.size = info["size"]
         out.name = info["name"]
         return out
-
-    def ukey(self, path):
-        return tokenize(path, self.fo, self.protocol)
